summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorHarsh Sharma <harsh.sharma@multitech.com>2020-11-09 14:10:34 -0600
committerHarsh Sharma <harsh.sharma@multitech.com>2020-11-09 14:10:34 -0600
commitff2949b92db803f04cb056f8b4f83d28db4faa07 (patch)
tree740acb95380fdfeb563535434f43b5c98dfe512a /src
parentf13e498b07f525c9e74e735761efc3150ab45224 (diff)
downloadmts-io-sysfs-ff2949b92db803f04cb056f8b4f83d28db4faa07.tar.gz
mts-io-sysfs-ff2949b92db803f04cb056f8b4f83d28db4faa07.tar.bz2
mts-io-sysfs-ff2949b92db803f04cb056f8b4f83d28db4faa07.zip
Changed mtcdt3 lora card identifier from product-id to hw version0.1.10
Diffstat (limited to 'src')
-rw-r--r--src/AccessoryCards/LoraCard15.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/AccessoryCards/LoraCard15.cpp b/src/AccessoryCards/LoraCard15.cpp
index cb7dc64..a7a1dad 100644
--- a/src/AccessoryCards/LoraCard15.cpp
+++ b/src/AccessoryCards/LoraCard15.cpp
@@ -19,10 +19,10 @@
Device::Lora15Card::Lora15Card(Device& d, const std::string ProductId, const std::string Port) : LoraCard(d, ProductId, Port) {
int ret;
- std::string deviceProductId = "";
- /* Map the spi path to the device and card product id, with the default being spidev0.0 */
- MTS::System::readFile(PRODUCT_ID_PATH, deviceProductId);
- if (deviceProductId.find("MTCDT3-") != std::string::npos) {
+ std::string deviceHwVersion = "";
+ /* Map the spi path to the device hw version/mtac product id, with the default being spidev0.0 */
+ MTS::System::readFile(HW_VERSION_PATH, deviceHwVersion);
+ if (deviceHwVersion.find("MTCDT3-") != std::string::npos) {
if (port.back() == '2') {
spiPath = "/dev/spidev1.2";
} else {